@@ -7,12 +7,13 @@
 #ifndef HTTPWORKER_H
 #define HTTPWORKER_H
 
-#include <QThread>
+#include <QNetworkReply>
 #include <QUrl>
 
 class QNetworkReply;
 namespace KNSCore
 {
+class HTTPWorkerPrivate;
 class HTTPWorker : public QObject
 {
     Q_OBJECT
@@ -23,7 +24,7 @@ public:
     };
     explicit HTTPWorker(const QUrl &url, JobType jobType = GetJob, QObject *parent = nullptr);
     explicit HTTPWorker(const QUrl &source, const QUrl &destination, JobType jobType = DownloadJob, QObject *parent = nullptr);
-    virtual ~HTTPWorker();
+    ~HTTPWorker() override;
 
     void startRequest();
 
@@ -34,13 +35,20 @@ public:
     Q_SIGNAL void completed();
     Q_SIGNAL void data(const QByteArray &data);
 
+    /**
+     * Fired in case there is a http error reported
+     * In some instances this is useful information for our users, and we want to make sure we report this centrally
+     * @param status The HTTP status code (fired in cases where it is perceived by QNetworkReply as an error)
+     * @param rawHeaders The raw HTTP headers for the errored-out network request
+     */
+    Q_SIGNAL void httpError(int status, QList<QNetworkReply::RawHeaderPair> rawHeaders);
+
     Q_SLOT void handleReadyRead();
     Q_SLOT void handleFinished();
     Q_SLOT void handleData(const QByteArray &data);
 
 private:
-    class Private;
-    Private *d;
+    const std::unique_ptr<HTTPWorkerPrivate> d;
 };
 
 }
