@@ -9,6 +9,9 @@
 
 #include <QAbstractListModel>
 
+#include "entry.h"
+#include "quickengine.h"
+
 #include <memory>
 
 class ItemsModelPrivate;
@@ -34,17 +37,17 @@ class ItemsModelPrivate;
  * @see NewStuffEntryComments
  *
  * \code
-    import org.kde.newstuff 1.0 as NewStuff
+    import org.kde.newstuff as NewStuff
     Item {
         NewStuff.ItemsModel {
-            id: newStuffModel;
+            id: newStuffModel
             engine: newStuffEngine
         }
         NewStuff.Engine {
             id: newStuffEngine
             configFile: "/some/filesystem/location/wallpaper.knsrc"
-            onBusyMessageChanged: () => console.log("KNS Message: " + newStuffEngine.busyMessage);
-            onErrorCode: (code, message, metadata) => console.log("KNS Error: " + message);
+            onBusyMessageChanged: () => console.log("KNS Message: " + newStuffEngine.busyMessage)
+            onErrorCode: (code, message, metadata) => console.log("KNS Error: " + message)
         }
     }
     \endcode
@@ -55,7 +58,7 @@ class ItemsModel : public QAbstractListModel
     /**
      * The NewStuffQuickEngine to show items from
      */
-    Q_PROPERTY(QObject *engine READ engine WRITE setEngine NOTIFY engineChanged REQUIRED)
+    Q_PROPERTY(Engine *engine READ engine WRITE setEngine NOTIFY engineChanged REQUIRED)
 public:
     explicit ItemsModel(QObject *parent = nullptr);
     ~ItemsModel() override;
@@ -89,30 +92,11 @@ public:
         DonationLinkRole,
         ProviderIdRole,
         SourceRole,
-        StatusRole,
         CommentsModelRole,
-        EntryTypeRole,
         EntryRole,
     };
     Q_ENUM(Roles)
-    enum ItemStatus { // TODO KF6 access those from KNSCore::Entry
-        InvalidStatus,
-        DownloadableStatus,
-        InstalledStatus,
-        UpdateableStatus,
-        DeletedStatus,
-        InstallingStatus,
-        UpdatingStatus,
-    };
-    Q_ENUM(ItemStatus)
 
-    /**
-     * Represents whether the current entry is an actual catalog entry,
-     * or an entry that represents a set of entries.
-     * @since 5.83
-     */
-    enum EntryType { CatalogEntry = 0, GroupEntry };
-    Q_ENUM(EntryType)
     // The lists in OCS are one-indexed, and that isn't how one usually does things in C++.
     // Consequently, this enum removes what would seem like magic numbers from the code, and
     // makes their meaning more explicit.
@@ -128,8 +112,8 @@ public:
     bool canFetchMore(const QModelIndex &parent) const override;
     void fetchMore(const QModelIndex &parent) override;
 
-    QObject *engine() const;
-    void setEngine(QObject *newEngine);
+    Engine *engine() const;
+    void setEngine(Engine *newEngine);
     Q_SIGNAL void engineChanged();
 
     /**
@@ -141,13 +125,17 @@ public:
      * @since 5.79
      */
     Q_INVOKABLE int indexOfEntryId(const QString &providerId, const QString &entryId);
+    Q_INVOKABLE int indexOfEntry(const KNSCore::Entry &e)
+    {
+        return indexOfEntryId(e.providerId(), e.uniqueId());
+    }
 
     /**
      * @brief Fired when an entry's data changes
      *
-     * @param index The index of the item which has changed
+     * @param entry The entry which has changed
      */
-    Q_SIGNAL void entryChanged(int index);
+    Q_SIGNAL void entryChanged(const KNSCore::Entry &entry);
 
 private:
     const std::unique_ptr<ItemsModelPrivate> d;
